Module parse_command

Module parse_command 

Functions

extract_shell_command
Extracts the shell and script from a command, regardless of platform
parse_command
DO NOT REVIEW THIS CODE BY HAND This parsing code is quite complex and not easy to hand-modify. The easiest way to iterate is to add unit tests and have Codex fix the implementation. To encourage this, the tests have been put directly below this function rather than at the bottom of the
parse_command_impl
parse_shell_script
Parses command metadata from a Bash-compatible shell script.
shlex_join